@@ -6,6 +6,7 @@ import (
 	"errors"
 	"fmt"
 	"math"
+	"os"
 	"strconv"
 	"strings"
 
@@ -168,6 +169,7 @@ func create_formatters() {
 		return ans
 	}
 	format_as_sgr.filler = only_open("bg=" + conf.Filler_bg.AsRGBSharp())
+	debugprintln(11111, conf.Margin_filler_bg.IsSet)
 	if conf.Margin_filler_bg.IsSet {
 		format_as_sgr.margin_filler = only_open("bg=" + conf.Margin_filler_bg.Color.AsRGBSharp())
 	} else {
@@ -571,7 +573,15 @@ func lines_for_diff(left_path string, right_path string, patch *Patch, columns,
 		is_full_width: true,
 	}
 	if patch.Len() == 0 {
-		for _, line := range splitlines("The files are identical", columns-margin_size) {
+		txt := "The files are identical"
+		if lstat, err := os.Stat(left_path); err == nil {
+			if rstat, err := os.Stat(right_path); err == nil {
+				if lstat.Mode() != rstat.Mode() {
+					txt = fmt.Sprintf("Mode changed: %s to %s", lstat.Mode(), rstat.Mode())
+				}
+			}
+		}
+		for _, line := range splitlines(txt, columns-margin_size) {
 			sl := ScreenLine{}
 			sl.left.marked_up_text = line
 			ht.screen_lines = append(ht.screen_lines, &sl)
@@ -752,7 +762,14 @@ func render(collection *Collection, diff_map map[string]*Patch, screen_size scre
 		}
 		return nil
 	})
-	return &LogicalLines{lines: ans[:len(ans)-1], margin_size: margin_size, columns: columns}, err
+	var ll []*LogicalLine
+	if len(ans) > 1 {
+		ll = ans[:len(ans)-1]
+	} else {
+		// Having am empty list of lines causes panics later on
+		ll = []*LogicalLine{{line_type: EMPTY_LINE, screen_lines: []*ScreenLine{{}}}}
+	}
+	return &LogicalLines{lines: ll, margin_size: margin_size, columns: columns}, err
 }
 
 func (self *LogicalLines) num_of_screen_lines() (ans int) {
