@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"kitty/tools/utils"
 	"os"
+	"os/user"
 	"path/filepath"
 	"testing"
 
@@ -14,6 +15,10 @@ import (
 
 var _ = fmt.Print
 
+type Pair struct {
+	Input, Uname, Host string
+}
+
 func TestSSHConfigParsing(t *testing.T) {
 	tdir := t.TempDir()
 	hostname := "unmatched"
@@ -47,6 +52,24 @@ func TestSSHConfigParsing(t *testing.T) {
 	rt()
 	conf = "env a=b"
 	rt(`export 'a'="b"`)
+
+	conf = "env a=\\"
+	rt(`export 'a'="\\"`)
+	conf = `env
+		\ a=
+		\\`
+	conf = "env\n \t \\ a=\n\\\\"
+	rt(`export 'a'="\\"`)
+	conf = `
+		e
+		\n
+		\v
+		\ a
+		\=
+		\\
+		\`
+	rt(`export 'a'="\\"`)
+
 	conf = "env a=b\nhostname 2\nenv a=c\nenv b=b"
 	rt(`export 'a'="b"`)
 	hostname = "2"
@@ -110,4 +133,20 @@ func TestSSHConfigParsing(t *testing.T) {
 		t.Fatal(ci)
 	}
 
+	u, _ := user.Current()
+	un := u.Username
+	for _, x := range []Pair{
+		{"localhost:12", un, "localhost:12"},
+		{"@localhost", un, "@localhost"},
+		{"ssh://@localhost:33", un, "localhost"},
+		{"me@localhost", "me", "localhost"},
+		{"ssh://me@localhost:12/something?else=1", "me", "localhost"},
+	} {
+		ue, uh := get_destination(x.Input)
+		q := Pair{x.Input, ue, uh}
+		if diff := cmp.Diff(x, q); diff != "" {
+			t.Fatalf("Failed: %s", diff)
+		}
+	}
+
 }
