@@ -558,6 +558,7 @@ cocoa_send_notification(PyObject *self UNUSED, PyObject *args) {
 @end
 
 // global menu {{{
+
 void
 cocoa_create_global_menu(void) {
     NSString* app_name = find_app_name();
@@ -683,7 +684,7 @@ cocoa_update_menu_bar_title(PyObject *pytitle) {
     if (OPT(macos_menubar_title_max_length) > 0 && PyUnicode_GetLength(pytitle) > OPT(macos_menubar_title_max_length)) {
         static char fmt[64];
         snprintf(fmt, sizeof(fmt), "%%%ld.%ldU%%s", OPT(macos_menubar_title_max_length), OPT(macos_menubar_title_max_length));
-        DECREF_AFTER_FUNCTION PyObject *st = PyUnicode_FromFormat(fmt, pytitle, "…");
+        RAII_PyObject(st, PyUnicode_FromFormat(fmt, pytitle, "…"));
         if (st) title = @(PyUnicode_AsUTF8(st));
     } else {
         title = @(PyUnicode_AsUTF8(pytitle));
@@ -697,7 +698,25 @@ cocoa_update_menu_bar_title(PyObject *pytitle) {
     NSMenu *m = [[NSMenu alloc] initWithTitle:[NSString stringWithFormat:@" :: %@", title]];
     [title_menu setSubmenu:m];
     [m release];
-} // }}}
+}
+
+void
+cocoa_clear_global_shortcuts(void) {
+    memset(&global_shortcuts, 0, sizeof(global_shortcuts));
+}
+
+void
+cocoa_recreate_global_menu(void) {
+    if (title_menu != NULL) {
+        NSMenu *bar = [NSApp mainMenu];
+        [bar removeItem:title_menu];
+    }
+    title_menu = NULL;
+    cocoa_create_global_menu();
+}
+
+
+// }}}
 
 #define NSLeftAlternateKeyMask  (0x000020 | NSEventModifierFlagOption)
 #define NSRightAlternateKeyMask (0x000040 | NSEventModifierFlagOption)
@@ -946,7 +965,7 @@ static PyMethodDef module_methods[] = {
 
 bool
 init_cocoa(PyObject *module) {
-    memset(&global_shortcuts, 0, sizeof(global_shortcuts));
+    cocoa_clear_global_shortcuts();
     if (PyModule_AddFunctions(module, module_methods) != 0) return false;
     register_at_exit_cleanup_func(COCOA_CLEANUP_FUNC, cleanup);
     return true;
