@@ -46,10 +46,10 @@
 void log_error(const char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
 #define fatal(...) { log_error(__VA_ARGS__); exit(EXIT_FAILURE); }
 static inline void cleanup_free(void *p) { free(*(void**)p); }
-#define FREE_AFTER_FUNCTION __attribute__((cleanup(cleanup_free)))
-static inline void cleanup_clear(void *p) { Py_XDECREF((PyObject *)p); }
-#define DECREF_AFTER_FUNCTION __attribute__((cleanup(cleanup_clear)))
-#define FREE_BUFFER_AFTER_FUNCTION __attribute__((cleanup(PyBuffer_Release)))
+#define RAII_ALLOC(type, name, initializer) __attribute__((cleanup(cleanup_free))) type *name = initializer
+static inline void cleanup_decref(PyObject **p) { Py_CLEAR(*p); }
+#define RAII_PyObject(name, initializer) __attribute__((cleanup(cleanup_decref))) PyObject *name = initializer
+#define RAII_PY_BUFFER(name) __attribute__((cleanup(PyBuffer_Release))) Py_buffer name = {0}
 
 typedef unsigned long long id_type;
 typedef uint32_t char_type;
@@ -346,7 +346,6 @@ attrs_to_cursor(const CellAttrs attrs, Cursor *c) {
 
 
 // Global functions
-const char* base64_decode(const uint32_t *src, size_t src_sz, uint8_t *dest, size_t dest_capacity, size_t *dest_sz);
 Line* alloc_line(void);
 Cursor* alloc_cursor(void);
 LineBuf* alloc_linebuf(unsigned int, unsigned int);
