@@ -18,11 +18,13 @@
 extern void cocoa_focus_window(void *w);
 extern long cocoa_window_number(void *w);
 extern void cocoa_create_global_menu(void);
+extern void cocoa_recreate_global_menu(void);
 extern void cocoa_system_beep(const char*);
 extern void cocoa_set_activation_policy(bool);
 extern bool cocoa_alt_option_key_pressed(unsigned long);
 extern void cocoa_toggle_secure_keyboard_entry(void);
 extern void cocoa_hide(void);
+extern void cocoa_clear_global_shortcuts(void);
 extern void cocoa_hide_others(void);
 extern void cocoa_minimize(void *w);
 extern void cocoa_set_uncaught_exception_handler(void);
@@ -92,7 +94,7 @@ update_menu_bar_title(PyObject *title UNUSED) {
 #ifdef __APPLE__
     static char buf[2048];
     strip_csi_(PyUnicode_AsUTF8(title), buf, arraysz(buf));
-    DECREF_AFTER_FUNCTION PyObject *stitle = PyUnicode_FromString(buf);
+    RAII_PyObject(stitle, PyUnicode_FromString(buf));
     cocoa_update_menu_bar_title(stitle);
 #endif
 }
@@ -264,11 +266,9 @@ window_pos_callback(GLFWwindow* window, int x UNUSED, int y UNUSED) {
 static void
 window_close_callback(GLFWwindow* window) {
     if (!set_callback_window(window)) return;
-    if (global_state.callback_os_window->close_request == NO_CLOSE_REQUESTED) {
-        global_state.callback_os_window->close_request = CONFIRMABLE_CLOSE_REQUESTED;
-        global_state.has_pending_closes = true;
-        request_tick_callback();
-    }
+    global_state.callback_os_window->close_request = CONFIRMABLE_CLOSE_REQUESTED;
+    global_state.has_pending_closes = true;
+    request_tick_callback();
     glfwSetWindowShouldClose(window, false);
     global_state.callback_os_window = NULL;
 }
@@ -703,6 +703,11 @@ set_default_window_icon(PyObject UNUSED *self, PyObject *args) {
     uint8_t *data;
     if(!PyArg_ParseTuple(args, "s", &path)) return NULL;
     if (png_path_to_bitmap(path, &data, &width, &height, &sz)) {
+#ifndef __APPLE__
+        if (!global_state.is_wayland && (width > 128 || height > 128)) {
+            return PyErr_Format(PyExc_ValueError, "The window icon is too large (%dx%d). On X11 max window icon size is: 128x128. Create a file called ~/.config/kitty.app-128.png containing a 128x128 image to use as the window icon on X11.", width, height);
+        }
+#endif
         logo.width = width; logo.height = height;
         logo.pixels = data;
     }
@@ -1746,6 +1751,17 @@ request_frame_render(OSWindow *w) {
     w->render_state = RENDER_FRAME_REQUESTED;
 }
 
+static PyObject*
+py_recreate_global_menu(PyObject *self UNUSED, PyObject *args UNUSED) {
+    cocoa_recreate_global_menu();
+    Py_RETURN_NONE;
+}
+
+static PyObject*
+py_clear_global_shortcuts(PyObject *self UNUSED, PyObject *args UNUSED) {
+    cocoa_clear_global_shortcuts();
+    Py_RETURN_NONE;
+}
 #else
 
 static void
@@ -1831,7 +1847,7 @@ strip_csi(PyObject *self UNUSED, PyObject *src) {
     Py_ssize_t sz;
     const char *title = PyUnicode_AsUTF8AndSize(src, &sz);
     if (!title) return NULL;
-    FREE_AFTER_FUNCTION char *buf = malloc(sz + 1);
+    RAII_ALLOC(char, buf, malloc(sz + 1));
     if (!buf) { return PyErr_NoMemory(); }
     strip_csi_(title, buf, sz + 1);
     return PyUnicode_FromString(buf);
@@ -1950,6 +1966,9 @@ static PyMethodDef module_methods[] = {
     METHODB(strip_csi, METH_O),
 #ifndef __APPLE__
     METHODB(dbus_send_notification, METH_VARARGS),
+#else
+    {"cocoa_recreate_global_menu", (PyCFunction)py_recreate_global_menu, METH_NOARGS, ""},
+    {"cocoa_clear_global_shortcuts", (PyCFunction)py_clear_global_shortcuts, METH_NOARGS, ""},
 #endif
     METHODB(cocoa_window_id, METH_O),
     METHODB(cocoa_hide_app, METH_NOARGS),
