@@ -24,7 +24,7 @@ PyTypeObject GraphicsManager_Type;
 
 #define DEFAULT_STORAGE_LIMIT 320u * (1024u * 1024u)
 #define REPORT_ERROR(...) { log_error(__VA_ARGS__); }
-#define FREE_CFD_AFTER_FUNCTION __attribute__((cleanup(cfd_free)))
+#define RAII_CoalescedFrameData(name, initializer) __attribute__((cleanup(cfd_free))) CoalescedFrameData name = initializer
 
 // caching {{{
 #define CACHE_KEY_BUFFER_SIZE 32
@@ -424,7 +424,7 @@ load_image_data(GraphicsManager *self, Image *img, const GraphicsCommand *g, con
             else fd = safe_open(fname, O_CLOEXEC | O_RDONLY | O_NONBLOCK, 0);  // O_NONBLOCK so that opening a FIFO pipe does not block
             if (fd == -1) ABRT("EBADF", "Failed to open file for graphics transmission with error: [%d] %s", errno, strerror(errno));
             if (global_state.boss && transmission_type != 's') {
-                DECREF_AFTER_FUNCTION PyObject *cret_ = PyObject_CallMethod(global_state.boss, "is_ok_to_read_image_file", "si", fname, fd);
+                RAII_PyObject(cret_, PyObject_CallMethod(global_state.boss, "is_ok_to_read_image_file", "si", fname, fd));
                 if (cret_ == NULL) {
                     PyErr_Print();
                     ABRT("EBADF", "Failed to check file for read permission");
@@ -983,12 +983,14 @@ grman_update_layers(GraphicsManager *self, unsigned int scrolled_by, float scree
     // Calculate the group counts
     i = 0;
     while (i < self->count) {
-        id_type image_id = self->render_data[i].image_id, start = i;
-        if (start == self->count - 1) i = self->count;
-        else {
-            while (i < self->count - 1 && self->render_data[++i].image_id == image_id) {}
+        id_type num_identical = 1, image_id = self->render_data[i].image_id, start = i;
+        while (++i < self->count) {
+            if (self->render_data[i].image_id != image_id) break;
+            num_identical++;
+        }
+        while (num_identical > 0) {
+            self->render_data[start++].group_count = num_identical--;
         }
-        self->render_data[start].group_count = i - start;
     }
     return true;
 }
@@ -1496,7 +1498,7 @@ scan_active_animations(GraphicsManager *self, const monotonic_t now, monotonic_t
 
 // {{{ composition a=c
 static void
-cfd_free(void *p) { free(((CoalescedFrameData*)p)->buf); }
+cfd_free(CoalescedFrameData *p) { free((p)->buf); p->buf = NULL; }
 
 static void
 handle_compose_command(GraphicsManager *self, bool *is_dirty, const GraphicsCommand *g, Image *img) {
@@ -1530,12 +1532,12 @@ handle_compose_command(GraphicsManager *self, bool *is_dirty, const GraphicsComm
         }
     }
 
-    FREE_CFD_AFTER_FUNCTION CoalescedFrameData src_data = get_coalesced_frame_data(self, img, src_frame);
+    RAII_CoalescedFrameData(src_data, get_coalesced_frame_data(self, img, src_frame));
     if (!src_data.buf) {
         set_command_failed_response("EINVAL", "Failed to get data for src frame: %u", g->frame_number - 1);
         return;
     }
-    FREE_CFD_AFTER_FUNCTION CoalescedFrameData dest_data = get_coalesced_frame_data(self, img, dest_frame);
+    RAII_CoalescedFrameData(dest_data, get_coalesced_frame_data(self, img, dest_frame));
     if (!dest_data.buf) {
         set_command_failed_response("EINVAL", "Failed to get data for destination frame: %u", g->other_frame_number - 1);
         return;
@@ -1688,6 +1690,12 @@ grman_remove_all_cell_images(GraphicsManager *self) {
 
 static bool
 clear_filter_func(const ImageRef *ref, Image UNUSED *img, const void UNUSED *data, CellPixelSize cell UNUSED) {
+    if (ref->is_virtual_ref) return false;
+    return ref->start_row + (int32_t)ref->effective_num_rows > 0;
+}
+
+static bool
+clear_filter_func_noncell(const ImageRef *ref, Image UNUSED *img, const void UNUSED *data, CellPixelSize cell UNUSED) {
     if (ref->is_virtual_ref || ref->is_cell_image) return false;
     return ref->start_row + (int32_t)ref->effective_num_rows > 0;
 }
@@ -1762,7 +1770,7 @@ handle_delete_command(GraphicsManager *self, const GraphicsCommand *g, Cursor *c
 #define D(l, u, data, func) case l: case u: I(u, data, func)
 #define G(l, u, func) D(l, u, g, func)
         case 0:
-        D('a', 'A', NULL, clear_filter_func);
+        D('a', 'A', NULL, clear_filter_func_noncell);
         G('i', 'I', id_filter_func);
         G('p', 'P', point_filter_func);
         G('q', 'Q', point3d_filter_func);
