@@ -12,12 +12,12 @@ from .child import Child
 from .cli import parse_args
 from .cli_stub import LaunchCLIOptions
 from .clipboard import set_clipboard_string, set_primary_selection
-from .constants import kitten_exe, shell_path
+from .constants import shell_path
 from .fast_data_types import add_timer, get_boss, get_options, get_os_window_title, patch_color_profiles
 from .options.utils import env as parse_env
 from .tabs import Tab, TabManager
 from .types import OverlayType, run_once
-from .utils import get_editor, log_error, resolve_custom_file, which
+from .utils import cmdline_for_hold, get_editor, log_error, resolve_custom_file, which
 from .window import CwdRequest, CwdRequestType, Watchers, Window
 
 try:
@@ -107,9 +107,16 @@ times to set different environment variables. Syntax: :code:`name=value`. Using
 environment variable.
 
 
+--var
+type=list
+User variables to set in the created window. Can be specified multiple
+times to set different user variables. Syntax: :code:`name=value`. Using
+:code:`name=` will set to empty string.
+
+
 --hold
 type=bool-set
-Keep the window open even after the command being executed exits.
+Keep the window open even after the command being executed exits, at a shell prompt.
 
 
 --copy-colors
@@ -252,6 +259,13 @@ titles set by programs running in kitty. The special value :code:`current` will
 use the title of the current OS window, if any.
 
 
+--os-window-state
+type=choices
+default=normal
+choices=normal,fullscreen,maximized,minimized
+The initial state for the newly created OS Window.
+
+
 --logo
 completion=type:file ext:png group:"PNG images" relative:conf
 Path to a PNG image to use as the logo for the newly created window. See
@@ -323,7 +337,11 @@ def tab_for_window(boss: Boss, opts: LaunchCLIOptions, target_tab: Optional[Tab]
 
     def create_tab(tm: Optional[TabManager] = None) -> Tab:
         if tm is None:
-            oswid = boss.add_os_window(wclass=opts.os_window_class, wname=opts.os_window_name, override_title=opts.os_window_title or None)
+            oswid = boss.add_os_window(
+                wclass=opts.os_window_class,
+                wname=opts.os_window_name,
+                window_state=opts.os_window_state,
+                override_title=opts.os_window_title or None)
             tm = boss.os_window_map[oswid]
         tab = tm.new_tab(empty_tab=True, location=opts.location)
         if opts.tab_title:
@@ -401,6 +419,12 @@ def apply_colors(window: Window, spec: Sequence[str]) -> None:
     patch_color_profiles(colors, profiles, True)
 
 
+def parse_var(defn: Iterable[str]) -> Iterator[Tuple[str, str]]:
+    for item in defn:
+        a, sep, b = item.partition('=')
+        yield a, b
+
+
 class ForceWindowLaunch:
 
     def __init__(self) -> None:
@@ -424,7 +448,7 @@ force_window_launch = ForceWindowLaunch()
 non_window_launch_types = 'background', 'clipboard', 'primary'
 
 
-def launch(
+def _launch(
     boss: Boss,
     opts: LaunchCLIOptions,
     args: List[str],
@@ -432,6 +456,7 @@ def launch(
     force_target_tab: bool = False,
     active: Optional[Window] = None,
     is_clone_launch: str = '',
+    rc_from_window: Optional[Window] = None,
 ) -> Optional[Window]:
     active = active or boss.active_window_for_cwd
     if active:
@@ -486,6 +511,8 @@ def launch(
                 kw['cwd_from'] = CwdRequest(active, CwdRequestType.root)
         else:
             kw['cwd'] = opts.cwd
+        if kw['cwd_from'] is not None and rc_from_window is not None:
+            kw['cwd_from'].rc_from_window_id = rc_from_window.id
     if opts.location != 'default':
         kw['location'] = opts.location
     if opts.copy_colors and active:
@@ -538,9 +565,10 @@ def launch(
                         elif x == '@last-line-on-screen':
                             x = str(screen.visual_line(screen.lines - 1) or '')
             final_cmd.append(x)
-        exe = which(final_cmd[0])
-        if exe:
-            final_cmd[0] = exe
+        if rc_from_window is None and final_cmd:
+            exe = which(final_cmd[0])
+            if exe:
+                final_cmd[0] = exe
         kw['cmd'] = final_cmd
     if force_window_launch and opts.type not in non_window_launch_types:
         opts.type = 'window'
@@ -564,34 +592,63 @@ def launch(
     else:
         if opts.hold:
             cmd = kw['cmd'] or [shell_path]
-            kw['cmd'] = [kitten_exe(), '__hold_till_enter__'] + cmd
+            if not os.path.isabs(cmd[0]):
+                cmd[0] = which(cmd[0]) or cmd[0]
+            kw['cmd'] = cmdline_for_hold(cmd)
         if force_target_tab:
             tab = target_tab
         else:
             tab = tab_for_window(boss, opts, target_tab)
         if tab is not None:
             watchers = load_watch_modules(opts.watcher)
-            new_window: Window = tab.new_window(env=env or None, watchers=watchers or None, is_clone_launch=is_clone_launch, **kw)
+            with Window.set_ignore_focus_changes_for_new_windows(opts.keep_focus):
+                new_window: Window = tab.new_window(
+                    env=env or None, watchers=watchers or None, is_clone_launch=is_clone_launch, **kw)
             if spacing:
                 patch_window_edges(new_window, spacing)
                 tab.relayout()
             if opts.color:
                 apply_colors(new_window, opts.color)
-            if opts.keep_focus and active:
-                boss.set_active_window(active, switch_os_window_if_needed=True, for_keep_focus=True)
+            if opts.keep_focus:
+                if active:
+                    boss.set_active_window(active, switch_os_window_if_needed=True, for_keep_focus=True)
+                if not Window.initial_ignore_focus_changes_context_manager_in_operation:
+                    new_window.ignore_focus_changes = False
             if opts.logo:
                 new_window.set_logo(opts.logo, opts.logo_position or '', opts.logo_alpha)
             if opts.type == 'overlay-main':
                 new_window.overlay_type = OverlayType.main
+            if opts.var:
+                for key, val in parse_var(opts.var):
+                    new_window.set_user_var(key, val)
             return new_window
     return None
 
 
+def launch(
+    boss: Boss,
+    opts: LaunchCLIOptions,
+    args: List[str],
+    target_tab: Optional[Tab] = None,
+    force_target_tab: bool = False,
+    active: Optional[Window] = None,
+    is_clone_launch: str = '',
+    rc_from_window: Optional[Window] = None,
+) -> Optional[Window]:
+    active = active or boss.active_window_for_cwd
+    if opts.keep_focus and active:
+        orig, active.ignore_focus_changes = active.ignore_focus_changes, True
+    try:
+        return _launch(boss, opts, args, target_tab, force_target_tab, active, is_clone_launch, rc_from_window)
+    finally:
+        if opts.keep_focus and active:
+            active.ignore_focus_changes = orig
+
 @run_once
 def clone_safe_opts() -> FrozenSet[str]:
     return frozenset((
-        'window_title', 'tab_title', 'type', 'keep_focus', 'cwd', 'env', 'hold',
-        'location', 'os_window_class', 'os_window_name', 'os_window_title',
+        'window_title', 'tab_title', 'type', 'keep_focus', 'cwd', 'env', 'var', 'hold',
+        'location', 'os_window_class', 'os_window_name', 'os_window_title', 'os_window_state',
         'logo', 'logo_position', 'logo_alpha', 'color', 'spacing',
     ))
 
@@ -674,7 +731,7 @@ class EditCmd:
         self.is_local_file = False
         with suppress(OSError):
             st = os.stat(self.file_localpath)
-            self.is_local_file = (st.st_dev, st.st_ino) == self.file_inode
+            self.is_local_file = (st.st_dev, st.st_ino) == self.file_inode and os.access(self.file_localpath, os.W_OK | os.R_OK)
         if not self.is_local_file:
             import tempfile
             self.tdir = tempfile.mkdtemp()
@@ -844,7 +901,6 @@ def clone_and_launch(msg: str, window: Window) -> None:
                 patch_cmdline('env', entry, cmdline)
             c.opts.env = []
     else:
-
         try:
             cmdline = window.child.cmdline_of_pid(c.pid)
         except Exception:
