@@ -28,13 +28,13 @@
 #endif
 
 static void cleanup_free(void *p) { free(*(void**) p); }
-#define FREE_AFTER_FUNCTION __attribute__((cleanup(cleanup_free)))
+#define RAII_ALLOC(type, name, initializer) __attribute__((cleanup(cleanup_free))) type *name = initializer
 
 
 #ifndef __FreeBSD__
 static bool
 safe_realpath(const char* src, char *buf, size_t buf_sz) {
-    FREE_AFTER_FUNCTION char* ans = realpath(src, NULL);
+    RAII_ALLOC(char, ans, realpath(src, NULL));
     if (ans == NULL) return false;
     snprintf(buf, buf_sz, "%s", ans);
     return true;
@@ -83,8 +83,8 @@ canonicalize_path(const char *srcpath, char *dstpath, size_t sz) {
     // remove . and .. path segments
     bool ok = false;
     size_t plen = strlen(srcpath) + 1, chk;
-    FREE_AFTER_FUNCTION char *wtmp = malloc(plen);
-    FREE_AFTER_FUNCTION char **tokv = malloc(sizeof(char*) * plen);
+    RAII_ALLOC(char, wtmp, malloc(plen));
+    RAII_ALLOC(char*, tokv, malloc(sizeof(char*) * plen));
     if (!wtmp || !tokv) goto end;
     char *s, *tok, *sav;
     bool relpath = *srcpath != '/';
@@ -182,6 +182,9 @@ run_embedded(RunData *run_data) {
     PyPreConfig_InitPythonConfig(&preconfig);
     preconfig.utf8_mode = 1;
     preconfig.coerce_c_locale = 1;
+#ifdef SET_PYTHON_HOME
+    preconfig.isolated = 1;
+#endif
     status = Py_PreInitialize(&preconfig);
     if (PyStatus_Exception(status)) goto fail;
     PyConfig config;
@@ -194,7 +197,15 @@ run_embedded(RunData *run_data) {
     if (PyStatus_Exception(status)) goto fail;
     status = PyConfig_SetBytesString(&config, &config.run_filename, run_data->lib_dir);
     if (PyStatus_Exception(status)) goto fail;
-
+#ifdef SET_PYTHON_HOME
+#ifndef __APPLE__
+    char pyhome[256];
+    snprintf(pyhome, sizeof(pyhome), "%s/%s", run_data->lib_dir, SET_PYTHON_HOME);
+    status = PyConfig_SetBytesString(&config, &config.home, pyhome);
+    if (PyStatus_Exception(status)) goto fail;
+#endif
+    config.isolated = 1;
+#endif
     status = Py_InitializeFromConfig(&config);
     if (PyStatus_Exception(status))  goto fail;
     PyConfig_Clear(&config);
@@ -349,7 +360,7 @@ int main(int argc, char *argv[], char* envp[]) {
     if (!ensure_working_stdio()) return 1;
     char exe[PATH_MAX+1] = {0};
     char exe_dir_buf[PATH_MAX+1] = {0};
-    FREE_AFTER_FUNCTION const char *lc_ctype = NULL;
+    RAII_ALLOC(const char, lc_ctype, NULL);
 #ifdef __APPLE__
     lc_ctype = getenv("LC_CTYPE");
     if (lc_ctype) lc_ctype = strdup(lc_ctype);
@@ -360,7 +371,11 @@ int main(int argc, char *argv[], char* envp[]) {
     delegate_to_kitten_if_possible(argc, argv, exe_dir);
     int num, ret=0;
     char lib[PATH_MAX+1] = {0};
-    num = snprintf(lib, PATH_MAX, "%s/%s", exe_dir, KITTY_LIB_PATH);
+    if (KITTY_LIB_PATH[0] == '/') {
+        num = snprintf(lib, PATH_MAX, "%s", KITTY_LIB_PATH);
+    } else {
+        num = snprintf(lib, PATH_MAX, "%s/%s", exe_dir, KITTY_LIB_PATH);
+    }
 
     if (num < 0 || num >= PATH_MAX) { fprintf(stderr, "Failed to create path to kitty lib\n"); return 1; }
     RunData run_data = {.exe = exe, .exe_dir = exe_dir, .lib_dir = lib, .argc = argc, .argv = argv, .lc_ctype = lc_ctype};
