@@ -594,6 +594,8 @@ def optional_edge_width(x: str) -> FloatEdges:
 def hide_window_decorations(x: str) -> int:
     if x == 'titlebar-only':
         return 0b10
+    if x == 'titlebar-and-corners':
+        return 0b100
     if to_bool(x):
         return 0b01
     return 0b00
@@ -613,7 +615,7 @@ def resize_debounce_time(x: str) -> Tuple[float, float]:
 
 def visual_window_select_characters(x: str) -> str:
     import string
-    valid_characters = string.digits + string.ascii_uppercase
+    valid_characters = string.digits + string.ascii_uppercase + "-=[]\\;',./`"
     ans = x.upper()
     ans_chars = set(ans)
     if not ans_chars.issubset(set(valid_characters)):
