@@ -8,6 +8,8 @@
 #define _POSIX_C_SOURCE 200809L
 
 #include "data-types.h"
+#define B64_INPUT_BITSIZE 32
+#include "base64.h"
 #include "control-codes.h"
 #include "screen.h"
 #include "graphics.h"
@@ -1168,7 +1170,7 @@ accumulate_osc(Screen *screen, uint32_t ch, PyObject DUMP_UNUSED *dump_callback,
         default:
             if (screen->parser_buf_pos >= PARSER_BUF_SZ - 1) {
                 if (handle_extended_osc_code(screen)) *extended_osc_code = true;
-                else REPORT_ERROR("OSC sequence too long, truncating.");
+                else REPORT_ERROR("OSC sequence too long (> %d bytes) truncating.", PARSER_BUF_SZ);
                 return true;
             }
             screen->parser_buf[screen->parser_buf_pos++] = ch;
@@ -1579,7 +1581,7 @@ do_parse_bytes(Screen *screen, const uint8_t *read_buf, const size_t read_buf_sz
 PyObject*
 FNAME(parse_bytes)(PyObject UNUSED *self, PyObject *args) {
     PyObject *dump_callback = NULL;
-    Py_buffer pybuf;
+    RAII_PY_BUFFER(pybuf);
     Screen *screen;
 #ifdef DUMP_COMMANDS
     if (!PyArg_ParseTuple(args, "OO!y*", &dump_callback, &Screen_Type, &screen, &pybuf)) return NULL;
