@@ -23,6 +23,7 @@ class Launch(RemoteCommand):
     window_title/str: Title for the new window
     cwd/str: Working directory for the new window
     env/list.str: List of environment variables of the form NAME=VALUE
+    var/list.str: List of user variables of the form NAME=VALUE
     tab_title/str: Title for the new tab
     type/choices.window.tab.os-window.overlay.overlay-main.background.clipboard.primary: The type of window to open
     keep_focus/bool: Boolean indicating whether the current window should retain focus or not
@@ -46,6 +47,7 @@ class Launch(RemoteCommand):
     os_window_title/str: Title for OS Window
     os_window_name/str: WM_NAME for OS Window
     os_window_class/str: WM_CLASS for OS Window
+    os_window_state/choices.normal.fullscreen.maximized.minimized: The initial state for OS Window
     color/list.str: list of color specifications such as foreground=red
     watcher/list.str: list of paths to watcher files
     '''
@@ -91,7 +93,7 @@ instead of the active tab
             target_tab = tabs[0]
         elif payload_get('type') not in ('background', 'os-window', 'tab', 'window'):
             return None
-        w = do_launch(boss, opts, payload_get('args') or [], target_tab=target_tab)
+        w = do_launch(boss, opts, payload_get('args') or [], target_tab=target_tab, rc_from_window=window)
         return None if payload_get('no_response') else str(getattr(w, 'id', 0))
 
 
