@@ -481,6 +481,7 @@ draw_graphics(int program, ssize_t vao_idx, ImageRenderData *data, GLuint start,
     for (GLuint i=0; i < count;) {
         ImageRenderData *group = data + start + i;
         glBindTexture(GL_TEXTURE_2D, group->texture_id);
+        if (group->group_count == 0) { i++; continue; }
         for (GLuint k=0; k < group->group_count; k++, i++) {
             ImageRenderData *rd = data + start + i;
             glUniform4f(u->src_rect, rd->src_rect.left, rd->src_rect.top, rd->src_rect.right, rd->src_rect.bottom);
@@ -938,7 +939,7 @@ draw_cells(ssize_t vao_idx, const ScreenRenderData *srd, OSWindow *os_window, bo
     } else wl = NULL;
     ImageRenderData *previous_graphics_render_data = NULL;
     if (os_window->live_resize.in_progress && screen->grman->count && (crd.x_ratio != 1 || crd.y_ratio != 1)) {
-        previous_graphics_render_data = malloc(sizeof(previous_graphics_render_data[0]) * screen->grman->count);
+        previous_graphics_render_data = malloc(sizeof(previous_graphics_render_data[0]) * screen->grman->capacity);
         if (previous_graphics_render_data) {
             memcpy(previous_graphics_render_data, screen->grman->render_data, sizeof(previous_graphics_render_data[0]) * screen->grman->count);
             for (size_t i = 0; i < screen->grman->count; i++)
@@ -1047,7 +1048,7 @@ draw_borders(ssize_t vao_idx, unsigned int num_border_rects, BorderRect *rect_bu
 
 static bool
 attach_shaders(PyObject *sources, GLuint program_id, GLenum shader_type) {
-    FREE_AFTER_FUNCTION const GLchar * * c_sources = calloc(sizeof(char*), PyTuple_GET_SIZE(sources));
+    RAII_ALLOC(const GLchar*, c_sources, calloc(sizeof(GLchar*), PyTuple_GET_SIZE(sources)));
     for (Py_ssize_t i = 0; i < PyTuple_GET_SIZE(sources); i++) {
         PyObject *temp = PyTuple_GET_ITEM(sources, i);
         if (!PyUnicode_Check(temp)) { PyErr_SetString(PyExc_TypeError, "shaders must be strings"); return false; }
