@@ -4,7 +4,6 @@
 import json
 import os
 import re
-import sys
 import weakref
 from collections import deque
 from contextlib import contextmanager, suppress
@@ -38,6 +37,7 @@ from .constants import (
     appname,
     clear_handled_signals,
     config_dir,
+    kitten_exe,
     wakeup_io_loop,
 )
 from .fast_data_types import (
@@ -90,6 +90,7 @@ from .types import MouseEvent, OverlayType, WindowGeometry, ac, run_once
 from .typing import BossType, ChildType, EdgeLiteral, TabType, TypedDict
 from .utils import (
     docs_url,
+    key_val_matcher,
     kitty_ansi_sanitizer_pat,
     log_error,
     open_cmd,
@@ -98,6 +99,7 @@ from .utils import (
     path_from_osc7_url,
     resolve_custom_file,
     resolved_shell,
+    sanitize_control_codes,
     sanitize_for_bracketed_paste,
     sanitize_title,
     sanitize_url_for_dispay_to_user,
@@ -143,7 +145,7 @@ class CwdRequest:
             return window.get_cwd_of_root_child() or ''
         return window.get_cwd_of_child(oldest=self.request_type is CwdRequestType.oldest) or ''
 
-    def modify_argv_for_launch_with_cwd(self, argv: List[str]) -> str:
+    def modify_argv_for_launch_with_cwd(self, argv: List[str], env: Optional[Dict[str, str]]=None) -> str:
         window = self.window
         if not window:
             return ''
@@ -153,10 +155,14 @@ class CwdRequest:
             if ssh_kitten_cmdline:
                 run_shell = argv[0] == resolved_shell(get_options())[0]
                 server_args = [] if run_shell else list(argv)
-                from kittens.ssh.utils import set_cwd_in_cmdline, set_server_args_in_cmdline
+                from kittens.ssh.utils import set_cwd_in_cmdline, set_env_in_cmdline, set_server_args_in_cmdline
                 argv[:] = ssh_kitten_cmdline
+                if argv and argv[0] == 'kitten':
+                    argv[0] = kitten_exe()
                 set_cwd_in_cmdline(reported_cwd, argv)
                 set_server_args_in_cmdline(server_args, argv, allocate_tty=not run_shell)
+                if env is not None:
+                    set_env_in_cmdline(env, argv, clone=False)
                 return ''
             if not window.child_is_remote and (self.request_type is CwdRequestType.last_reported or window.at_prompt):
                 return reported_cwd
@@ -199,6 +205,7 @@ class WindowDict(TypedDict):
     is_self: bool
     lines: int
     columns: int
+    user_vars: Dict[str, str]
 
 
 class PipeData(TypedDict):
@@ -517,7 +524,7 @@ class Window:
         self.default_title = os.path.basename(child.argv[0] or appname)
         self.child_title = self.default_title
         self.title_stack: Deque[str] = deque(maxlen=10)
-        self.user_vars: Dict[str, bytes] = {}
+        self.user_vars: Dict[str, str] = {}
         self.id: int = add_window(tab.os_window_id, tab.id, self.title)
         self.clipboard_request_manager = ClipboardRequestManager(self.id)
         self.margin = EdgeWidths()
@@ -630,20 +637,21 @@ class Window:
         return f'Window(title={self.title}, id={self.id})'
 
     def as_dict(self, is_focused: bool = False, is_self: bool = False, is_active: bool = False) -> WindowDict:
-        return dict(
-            id=self.id,
-            is_focused=is_focused,
-            is_active=is_active,
-            title=self.title,
-            pid=self.child.pid,
-            cwd=self.child.current_cwd or self.child.cwd,
-            cmdline=self.child.cmdline,
-            env=self.child.environ,
-            foreground_processes=self.child.foreground_processes,
-            is_self=is_self,
-            lines=self.screen.lines,
-            columns=self.screen.columns,
-        )
+        return {
+            'id': self.id,
+            'is_focused': is_focused,
+            'is_active': is_active,
+            'title': self.title,
+            'pid': self.child.pid,
+            'cwd': self.child.current_cwd or self.child.cwd,
+            'cmdline': self.child.cmdline,
+            'env': self.child.environ,
+            'foreground_processes': self.child.foreground_processes,
+            'is_self': is_self,
+            'lines': self.screen.lines,
+            'columns': self.screen.columns,
+            'user_vars': self.user_vars,
+        }
 
     def serialize_state(self) -> Dict[str, Any]:
         ans = {
@@ -665,6 +673,8 @@ class Window:
             ans['window_custom_type'] = self.window_custom_type
         if self.overlay_type is not OverlayType.transient:
             ans['overlay_type'] = self.overlay_type.value
+        if self.user_vars:
+            ans['user_vars'] = self.user_vars
         return ans
 
     @property
@@ -689,15 +699,13 @@ class Window:
     def matches(self, field: str, pat: MatchPatternType) -> bool:
         if not pat:
             return False
-        if field == 'env':
-            assert isinstance(pat, tuple)
-            key_pat, val_pat = pat
-            for key, val in self.child.environ.items():
-                if key_pat.search(key) is not None and (
-                        val_pat is None or val_pat.search(val) is not None):
-                    return True
+
+        if isinstance(pat, tuple):
+            if field == 'env':
+                return key_val_matcher(self.child.environ.items(), *pat)
+            if field == 'var':
+                return key_val_matcher(self.user_vars.items(), *pat)
             return False
-        assert not isinstance(pat, tuple)
 
         if field in ('id', 'window_id'):
             return pat.pattern == str(self.id)
@@ -747,7 +755,22 @@ class Window:
             if query == 'overlay_parent':
                 return self_window is not None and self is self_window.overlay_parent
             return False
-        pat = compile_match_query(query, field != 'env')
+        if field == 'neighbor':
+            t = get_boss().active_tab
+            if t is None:
+                return False
+            gid: Optional[int] = None
+            if query == 'left':
+                gid = t.neighboring_group_id("left")
+            elif query == 'right':
+                gid = t.neighboring_group_id("right")
+            elif query == 'top':
+                gid = t.neighboring_group_id("top")
+            elif query == 'bottom':
+                gid = t.neighboring_group_id("bottom")
+            return gid is not None and t.windows.active_window_in_group_id(gid) is self
+
+        pat = compile_match_query(query, field not in ('env', 'var'))
         return self.matches(field, pat)
 
     def set_visible_in_layout(self, val: bool) -> None:
@@ -842,13 +865,16 @@ class Window:
         self.override_title = title or None
         self.title_updated()
 
-    def set_user_var(self, key: str, val: Optional[bytes]) -> None:
+    def set_user_var(self, key: str, val: Optional[Union[str, bytes]]) -> None:
+        key = sanitize_control_codes(key).replace('\n', ' ')
         self.user_vars.pop(key, None)  # ensure key will be newest in user_vars even if already present
         if len(self.user_vars) > 64:  # dont store too many user vars
             oldest_key = next(iter(self.user_vars))
             self.user_vars.pop(oldest_key)
         if val is not None:
-            self.user_vars[key] = val
+            if isinstance(val, bytes):
+                val = val.decode('utf-8', 'replace')
+            self.user_vars[key] = sanitize_control_codes(val).replace('\n', ' ')
 
     # screen callbacks {{{
 
@@ -1198,8 +1224,7 @@ class Window:
 
     def handle_remote_print(self, msg: str) -> None:
         text = process_remote_print(msg)
-        print(text, end='', file=sys.stderr)
-        sys.stderr.flush()
+        print(text, end='', flush=True)
 
     def send_cmd_response(self, response: Any) -> None:
         self.screen.send_escape_code_to_child(DCS, '@kitty-cmd' + json.dumps(response))
