@@ -11,6 +11,7 @@ import struct
 import sys
 import termios
 import time
+from contextlib import contextmanager
 from pty import CHILD, STDIN_FILENO, STDOUT_FILENO, fork
 from unittest import TestCase
 
@@ -28,6 +29,7 @@ class Callbacks:
     def __init__(self, pty=None) -> None:
         self.clear()
         self.pty = pty
+        self.ftc = None
 
     def write(self, data) -> None:
         self.wtcbuf += data
@@ -96,7 +98,7 @@ class Callbacks:
 
     def handle_remote_print(self, msg):
         text = process_remote_print(msg)
-        print(text, file=sys.__stderr__)
+        print(text, file=sys.__stdout__, end='', flush=True)
 
     def handle_remote_clone(self, msg):
         if not msg:
@@ -123,6 +125,10 @@ class Callbacks:
             data = standard_b64decode(msg)
             self.pty.write_to_child(data)
 
+    def file_transmission(self, data):
+        if self.ftc:
+            self.ftc.handle_serialized_command(data)
+
 
 def filled_line_buf(ynum=5, xnum=5, cursor=Cursor()):
     ans = LineBuf(ynum, xnum)
@@ -195,6 +201,24 @@ class BaseTest(TestCase):
             c1.x, c1.y, c2.x, c2.y = x1, y1, x2, y2
 
 
+debug_stdout = debug_stderr = -1
+
+
+@contextmanager
+def forwardable_stdio():
+    global debug_stderr, debug_stdout
+    debug_stdout = fd = os.dup(sys.stdout.fileno())
+    os.set_inheritable(fd, True)
+    debug_stderr = fd = os.dup(sys.stderr.fileno())
+    os.set_inheritable(fd, True)
+    try:
+        yield
+    finally:
+        os.close(debug_stderr)
+        os.close(debug_stdout)
+        debug_stderr = debug_stdout = -1
+
+
 class PTY:
 
     def __init__(
@@ -211,6 +235,7 @@ class PTY:
         else:
             self.child_pid, self.master_fd = fork()
             self.is_child = self.child_pid == CHILD
+        self.child_waited_for = False
         if self.is_child:
             while read_screen_size().width != columns * cell_width:
                 time.sleep(0.01)
@@ -223,7 +248,10 @@ class PTY:
                 os.dup2(stdout_fd, STDOUT_FILENO)
                 os.close(stdout_fd)
             signal.pthread_sigmask(signal.SIG_SETMASK, ())
-            os.execvpe(argv[0], argv, env or os.environ)
+            env = os.environ if env is None else env
+            if debug_stdout > -1:
+                env['KITTY_STDIO_FORWARDED'] = str(debug_stdout)
+            os.execvpe(argv[0], argv, env)
         if stdin_fd is not None:
             os.close(stdin_fd)
         if stdout_fd is not None:
@@ -253,6 +281,9 @@ class PTY:
             if hasattr(self, 'slave_fd'):
                 os.close(self.slave_fd)
                 del self.slave_fd
+            if self.child_pid > 0 and not self.child_waited_for:
+                os.waitpid(self.child_pid, 0)
+                self.child_waited_for = True
 
     def write_to_child(self, data, flush=False):
         if isinstance(data, str):
@@ -295,6 +326,21 @@ class PTY:
         if not q():
             raise TimeoutError(f'The condition was not met. Screen contents: \n {repr(self.screen_contents())}')
 
+    def wait_till_child_exits(self, timeout=30 if BaseTest.is_ci else 10, require_exit_code=None):
+        end_time = time.monotonic() + timeout
+        while time.monotonic() <= end_time:
+            si_pid, status = os.waitpid(self.child_pid, os.WNOHANG)
+            if si_pid == self.child_pid and os.WIFEXITED(status):
+                ec = os.waitstatus_to_exitcode(status) if hasattr(os, 'waitstatus_to_exitcode') else require_exit_code
+                self.child_waited_for = True
+                if require_exit_code is not None and ec != require_exit_code:
+                    raise AssertionError(
+                        f'Child exited with exit status: {status} code: {ec} != {require_exit_code}.'
+                        f' Screen contents:\n{self.screen_contents()}')
+                return status
+            self.process_input_from_child(timeout=0.02)
+        raise AssertionError(f'Child did not exit in {timeout} seconds. Screen contents:\n{self.screen_contents()}')
+
     def set_window_size(self, rows=25, columns=80, send_signal=True):
         if hasattr(self, 'screen'):
             self.screen.resize(rows, columns)
