@@ -308,12 +308,12 @@ func (self *Command) GetVisibleOptions() ([]string, map[string][]*Option) {
 }
 
 func sort_levenshtein_matches(q string, matches []string) {
-	utils.StableSort(matches, func(a, b string) bool {
+	utils.StableSort(matches, func(a, b string) int {
 		la, lb := utils.LevenshteinDistance(a, q, true), utils.LevenshteinDistance(b, q, true)
 		if la != lb {
-			return la < lb
+			return la - lb
 		}
-		return a < b
+		return strings.Compare(a, b)
 	})
 
 }
@@ -417,12 +417,9 @@ func (self *Command) FindOptions(name_with_hyphens string) []*Option {
 	depth := 0
 	for p := self.Parent; p != nil; p = p.Parent {
 		depth++
-		x := p.FindOptions(name_with_hyphens)
-		if x != nil {
-			for _, po := range x {
-				if po.Depth >= depth {
-					ans = append(ans, po)
-				}
+		for _, po := range p.FindOptions(name_with_hyphens) {
+			if po.Depth >= depth {
+				ans = append(ans, po)
 			}
 		}
 	}
