@@ -6,7 +6,7 @@ import (
 	"encoding/base64"
 	"fmt"
 	"os"
-	"runtime/debug"
+	"runtime"
 	"strings"
 	"time"
 
@@ -47,7 +47,8 @@ type Loop struct {
 	timers, timers_temp                    []*timer
 	timer_id_counter, write_msg_id_counter IdType
 	wakeup_channel                         chan byte
-	pending_writes                         []*write_msg
+	pending_writes                         []write_msg
+	tty_write_channel                      chan write_msg
 	pending_mouse_events                   *utils.RingBuffer[MouseEvent]
 	on_SIGTSTP                             func() error
 	style_cache                            map[string]func(...any) string
@@ -82,7 +83,7 @@ type Loop struct {
 	OnResize func(old_size ScreenSize, new_size ScreenSize) error
 
 	// Called when writing is done
-	OnWriteComplete func(msg_id IdType) error
+	OnWriteComplete func(msg_id IdType, has_pending_writes bool) error
 
 	// Called when a response to an rc command is received
 	OnRCResponse func(data []byte) error
@@ -98,6 +99,12 @@ type Loop struct {
 
 	// Called when main loop is woken up
 	OnWakeup func() error
+
+	// Called on SIGINT return true if you wish to handle it yourself
+	OnSIGINT func() (bool, error)
+
+	// Called on SIGTERM return true if you wish to handle it yourself
+	OnSIGTERM func() (bool, error)
 }
 
 func New(options ...func(self *Loop)) (*Loop, error) {
@@ -112,6 +119,10 @@ func (self *Loop) AddTimer(interval time.Duration, repeats bool, callback TimerC
 	return self.add_timer(interval, repeats, callback)
 }
 
+func (self *Loop) CallSoon(callback TimerCallback) (IdType, error) {
+	return self.add_timer(0, false, callback)
+}
+
 func (self *Loop) RemoveTimer(id IdType) bool {
 	return self.remove_timer(id)
 }
@@ -192,8 +203,8 @@ func (self *Loop) KillIfSignalled() {
 }
 
 func (self *Loop) Println(args ...any) {
-	self.QueueWriteString(fmt.Sprint(args...))
-	self.QueueWriteString("\r\n")
+	self.QueueWriteString(fmt.Sprintln(args...))
+	self.QueueWriteString("\r")
 }
 
 func (self *Loop) SprintStyled(style string, args ...any) string {
@@ -241,11 +252,20 @@ func (self *Loop) DebugPrintln(args ...any) {
 func (self *Loop) Run() (err error) {
 	defer func() {
 		if r := recover(); r != nil {
-			stack := utils.Splitlines(string(debug.Stack()))
-			err = fmt.Errorf("Paniced: %s", r)
-			fmt.Fprintf(os.Stderr, "\r\nPaniced with error: %s\r\nStacktrace:\r\n", r)
-			for _, line := range stack {
-				fmt.Fprintf(os.Stderr, "%s\r\n", line)
+			pcs := make([]uintptr, 256)
+			n := runtime.Callers(2, pcs)
+			frames := runtime.CallersFrames(pcs[:n])
+			err = fmt.Errorf("Panicked: %s", r)
+			fmt.Fprintf(os.Stderr, "\r\nPanicked with error: %s\r\nStacktrace (most recent call first):\r\n", r)
+			found_first_frame := false
+			for frame, more := frames.Next(); more; frame, more = frames.Next() {
+				if !found_first_frame {
+					if strings.HasPrefix(frame.Function, "runtime.") {
+						continue
+					}
+					found_first_frame = true
+				}
+				fmt.Fprintf(os.Stderr, "%s\r\n\t%s:%d\r\n", frame.Function, frame.File, frame.Line)
 			}
 			if self.terminal_options.alternate_screen {
 				term, err := tty.OpenControllingTerm(tty.SetRaw)
@@ -273,7 +293,7 @@ func (self *Loop) WakeupMainThread() bool {
 func (self *Loop) QueueWriteString(data string) IdType {
 	self.write_msg_id_counter++
 	msg := write_msg{str: data, bytes: nil, id: self.write_msg_id_counter}
-	self.add_write_to_pending_queue(&msg)
+	self.add_write_to_pending_queue(msg)
 	return msg.id
 }
 
@@ -282,7 +302,7 @@ func (self *Loop) QueueWriteString(data string) IdType {
 func (self *Loop) UnsafeQueueWriteBytes(data []byte) IdType {
 	self.write_msg_id_counter++
 	msg := write_msg{bytes: data, id: self.write_msg_id_counter}
-	self.add_write_to_pending_queue(&msg)
+	self.add_write_to_pending_queue(msg)
 	return msg.id
 }
 
