@@ -16,6 +16,7 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
+	"sync"
 
 	"kitty/tools/utils"
 	"kitty/tools/utils/shm"
@@ -216,7 +217,7 @@ func check_resize(frame *ImageFrame, filename string) error {
 }
 
 func (frame *ImageFrame) set_delay(min_gap, delay int) {
-	frame.Delay_ms = int32(utils.Max(min_gap, delay) * 10)
+	frame.Delay_ms = int32(max(min_gap, delay) * 10)
 	if frame.Delay_ms == 0 {
 		frame.Delay_ms = -1 // gapless frame in the graphics protocol
 	}
@@ -244,7 +245,7 @@ func OpenNativeImageFromReader(f io.ReadSeeker) (ans *ImageData, err error) {
 	if err != nil {
 		return nil, err
 	}
-	f.Seek(0, os.SEEK_SET)
+	f.Seek(0, io.SeekStart)
 	ans = &ImageData{Width: c.Width, Height: c.Height, Format_uppercase: strings.ToUpper(fmt)}
 
 	if ans.Format_uppercase == "GIF" {
@@ -264,7 +265,7 @@ func OpenNativeImageFromReader(f io.ReadSeeker) (ans *ImageData, err error) {
 	return
 }
 
-var MagickExe = utils.Once(func() string {
+var MagickExe = sync.OnceValue(func() string {
 	return utils.FindExe("magick")
 })
 
@@ -308,7 +309,7 @@ func parse_identify_record(ans *IdentifyRecord, raw *IdentifyOutput) (err error)
 		if err != nil {
 			return fmt.Errorf("Invalid gap value in identify output: %s", raw.Gap)
 		}
-		ans.Gap = utils.Max(0, ans.Gap)
+		ans.Gap = max(0, ans.Gap)
 	}
 	area, pos, found := strings.Cut(raw.Canvas, "+")
 	ok := false
@@ -400,7 +401,7 @@ func IdentifyWithMagick(path string) (ans []IdentifyRecord, err error) {
 	cmd = append(cmd, "-format", q, "--", path)
 	output, err := RunMagick(path, cmd)
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Failed to identify image at path: %s with error: %w", path, err)
 	}
 	output = bytes.TrimRight(bytes.TrimSpace(output), ",")
 	raw_json := make([]byte, 0, len(output)+2)
@@ -410,7 +411,7 @@ func IdentifyWithMagick(path string) (ans []IdentifyRecord, err error) {
 	var records []IdentifyOutput
 	err = json.Unmarshal(raw_json, &records)
 	if err != nil {
-		return nil, fmt.Errorf("The ImageMagick identify program returned malformed output, with error: %w", err)
+		return nil, fmt.Errorf("The ImageMagick identify program returned malformed output for the image at path: %s, with error: %w", path, err)
 	}
 	ans = make([]IdentifyRecord, len(records))
 	for i, rec := range records {
@@ -563,7 +564,7 @@ func RenderWithMagick(path string, ro *RenderOptions, frames []IdentifyRecord) (
 		err = fmt.Errorf("Failed to render %d out of %d frames", len(frames)-len(ans), len(frames))
 		return
 	}
-	slices.SortFunc(ans, func(a, b *ImageFrame) bool { return a.Number < b.Number })
+	slices.SortFunc(ans, func(a, b *ImageFrame) int { return a.Number - b.Number })
 	anchor_frame := 1
 	for i, frame := range ans {
 		anchor_frame, frame.Compose_onto = SetGIFFrameDisposal(frame.Number, anchor_frame, byte(frames[i].Disposal))
